@@ -33,7 +33,7 @@
  *	@(#)telnet.h	8.2 (Berkeley) 12/15/93
  */
 
-/* 	$Id: telnet.h,v 1.2 1995/07/26 11:43:09 martin Exp $	 */
+/* 	$Id: telnet.h,v 1.3 1996/06/13 14:11:52 martin Exp $	 */
 
 #ifndef _TELNET_H_
 #define	_TELNET_H_
@@ -269,7 +269,10 @@ extern char *slc_names[];
 
 #ifdef USE_SSL
 #define AUTHTYPE_SSL		7
-#endif
+#define N_AUTHTYPE		8
+#else /* !USE_SSL */
+#define N_AUTHTYPE		7
+#endif /* USE_SSL */
 
 #define	AUTHTYPE_TEST		99
 
