@@ -35,10 +35,10 @@
 static char sccsid[] = "@(#)utilities.c	8.2 (Berkeley) 12/15/93";
 #endif /* not lint */
 
-/* 	$Id: utilities.c,v 1.4 1995/11/15 09:14:42 martin Exp martin $	 */
+/* 	$Id: utilities.c,v 1.6 1996/02/01 12:07:52 martin Exp $	 */
 
 #ifndef lint
-static char vcid[] = "$Id: utilities.c,v 1.4 1995/11/15 09:14:42 martin Exp martin $";
+static char vcid[] = "$Id: utilities.c,v 1.6 1996/02/01 12:07:52 martin Exp $";
 #endif /* lint */
 
 #include "../config.h"
@@ -64,11 +64,11 @@ static char vcid[] = "$Id: utilities.c,v 1.4 1995/11/15 09:14:42 martin Exp mart
 #if defined(HAVE_SYS_SELECT_H) && !defined(SCO)
 # include <sys/select.h>
 #endif
-#if defined(__ultrix)
+/*#if defined(__ultrix)
 # include <cxx/sys/socket.h>
-#else
+#else*/
 # include <sys/socket.h>
-#endif
+/*#endif*/
 
 #include <ctype.h>
 
